/**
 * @fileoverview Every dangerouslySetInnerHTML must be called its security method
 * @author Kathiresan
 */
'use strict';

const DANGEROUS_MESSAGE =
  'Every dangerouslySetInnerHTML must be called its security method';

module.exports = {
  meta: {
    docs: {
      description:
        'Every dangerouslySetInnerHTML must be called its security method',
      category: 'Security Mistakes',
      recommended: false
    },
    fixable: null,
    schema: []
  },

  create: function(context) {
    return {
      JSXAttribute: function(node) {
        if (node) {
          if (node.hasOwnProperty('name')) {
            if (node.name.name !== 'dangerouslySetInnerHTML') {
              return;
            }
          }
          if (node.hasOwnProperty('value')) {
            if (node.value.hasOwnProperty('expression')) {
              if (
                node.value.expression.hasOwnProperty('properties') &&
                Array.isArray(node.value.expression.properties)
              ) {
                if (
                  node.value.expression.properties[0].hasOwnProperty('value')
                ) {
                  if (
                    node.value.expression.properties[0].value.hasOwnProperty(
                      'type'
                    )
                  ) {
                    if (
                      node.value.expression.properties[0].value.type ===
                      'Identifier'
                    ) {
                      context.report({
                        node: node,
                        message: DANGEROUS_MESSAGE
                      });
                    }
                  }
                }
              }
            }
          }
        }
      }
    };
  }
};
